@@ -31,8 +31,6 @@ if not path.exists(path.expanduser("~/.yahi")):
 
 locale.setlocale(locale.LC_ALL,"C")
 
-
-
 class ToxicSet(Copier,set):
     """a set for wich add is a shortcut for union
     this way, I can now select all the distinct stuffs
@@ -142,11 +140,13 @@ def shoot( context, group_by,):
     
     look_for = log_pattern[context.log_format].search
     match = None
+    matched = 0
+    parsed = 0
     dt_format = dt_formater_from_format(date_pattern[context.log_format])
     parse_user_agent = lru_cache(context.cache_size)(normalize_user_agent)
 
     if "geo_ip" in context.skill:
-        from pygeoip import GeoIP
+        from pygeoip import GeoIP, GeoIPError
         gi = GeoIP(path.expanduser(path.join(context.geoip, "GeoIP.dat")))
         country_by_ip = lru_cache(context.cache_size)(gi.country_code_by_addr)
         gi6 = GeoIP(path.expanduser(path.join(context.geoip, "GeoIPv6.dat")))
@@ -157,8 +157,9 @@ def shoot( context, group_by,):
     try:
         for line in _input:
             match = look_for(line)
-                
+            parsed += 1
             if match:
+                matched+=1
                 data = match.groupdict()
                 if dt := dt_format(data.get("datetime")):
                     data['_datetime']=dt
@@ -167,10 +168,12 @@ def shoot( context, group_by,):
                     data['_date'] = dt.date().isoformat()
 
                 if 'geo_ip' in context.skill:
+                    country="unknown"
                     try:
-                        data.update( {"_country":country_by_ip(data["ip"])})
-                    except:
-                        data.update( {"_country":country_by_ip6(data["ip"])})
+                        country = country_by_ip(data["ip"])
+                    except GeoIPError:
+                        country = country_by_ip6(data["ip"])
+                    data.update({"_country":country})
 
                 if 'user_agent' in context.skill:
                     data.update(
@@ -214,7 +217,8 @@ def shoot( context, group_by,):
         #_input.close()
         sys.stderr.write("\n")
         if not context.silent:
-            sys.stderr.write("\n%s lines parsed\n" % _input.lineno())
+            sys.stderr.write("\n%s lines parsed" % parsed)
+            sys.stderr.write("\n%d lines matched\n" % matched)
     return aggregator
 
 #################### CLI and DOC #################################
